==> H2H_Creator_startgg-0.4.2.0.5.tar.gz: H2H_Creator_startgg-0.4.2.0.5/H2H_Creator_startgg/results.py <==
# File for getting all results from list of players and events

import json
from time import sleep
from H2H_Creator_startgg.api import run_query
from H2H_Creator_startgg.events import get_events
from H2H_Creator_startgg.players import get_players_info
from H2H_Creator_startgg.queries import RESULTS_QUERY
from H2H_Creator_startgg.exceptions import *

def get_results(events:list, players:list, save_json:bool, header, sleep_time):
    results = {}

    for e in events:
        print("Now doing event {}".format(e))
        sets = [] # List of sets
        i = 1 # Page

        done = False

        while (not done):
            if i % 35 == 0: # Sleeping so startgg server doesn't hate me
                print("Sleeping for {} seconds".format(sleep_time))
                sleep(sleep_time)

            variables = {"slug": e, "page": i}
            response = run_query(RESULTS_QUERY, variables, header) # Send request

            if response == 500 or response == 429 or response == 404 or response == 400: # If server error
                print("Error code {} Retrying page {} in 10 seconds".format(response, i))
                i -= 1
                sleep(10)

            elif 'data' not in response: # Error
                return
            elif response['data']['event'] is None: # Error
                return
            elif response['data']['event']['sets']['nodes'] is None: # Error
                return
            elif response['data']['event']['sets']['nodes'] == []: # If pagination completed
                done = True
            
            print("Page {}".format(i)) # Console logging
            i += 1 # iteration for next time

            if type(response) is not int:
                for s in response['data']['event']['sets']['nodes']: # Iterate through all sets
                    bad_set = False
                    try:
                        player1 = s['slots'][0]['entrant']['participants'][0]['player']['user']['slug'].split('/')[1] # Gets user slug of player #1
                    except(TypeError):
                        bad_set = True
                        print("Player with tag {tag} didn't have a user account".
                            format(tag=s['slots'][0]['entrant']['participants'][0]['player']['gamerTag']))
                        
                    try:
                        player2 = s['slots'][1]['entrant']['participants'][0]['player']['user']['slug'].split('/')[1] # Gets user slug of player #2
                    except(TypeError):
                        bad_set = True
                        print("Player with tag {tag} didn't have a user account".
                            format(tag=s['slots'][1]['entrant']['participants'][0]['player']['gamerTag']))

                    if not bad_set:
                        if (player1 in players or player2 in players): # If either player is in the list
                            if (s not in sets): # Prevent duplicate sets
                                sets.append(s) # Append set to sets list
                

        results[e] = {
            # Will add more info
            # 'tournamentName': e['tournament']['name'],
            # 'tournamentId': e['tournament']['name'],
            # 'eventName': e['name'],
            # 'eventId': e['id'],
            'sets': sets
        }

    if save_json: # Outputting json file if flag activated
        with open('tournament_results.json', 'w+', encoding='utf-8') as outfile:
            json.dump(results, outfile, indent=4)

    return results

==> H2H_Creator_startgg-0.4.2.0.8.tar.gz: H2H_Creator_startgg-0.4.2.0.8/H2H_Creator_startgg/results.py <==
# File for getting all results from list of players and events

import json
from time import sleep
from H2H_Creator_startgg.api import run_query
from H2H_Creator_startgg.events import get_events
from H2H_Creator_startgg.players import get_players_info
from H2H_Creator_startgg.queries import RESULTS_QUERY
from H2H_Creator_startgg.exceptions import *

def get_results(events:list, players:list, save_json:bool, header, sleep_time):
    results = {}

    for e in events:
        print("Now doing event {}".format(e))
        sets = [] # List of sets
        i = 1 # Page

        done = False

        while (not done):
            if i % 35 == 0: # Sleeping so startgg server doesn't hate me
                print("Sleeping for {} seconds".format(sleep_time))
                sleep(sleep_time)

            variables = {"slug": e, "page": i}
            response = run_query(RESULTS_QUERY, variables, header) # Send request

            if response == 500 or response == 429 or response == 404 or response == 400: # If server error
                print("Error code {} Retrying page {} in 10 seconds".format(response, i))
                i -= 1
                sleep(10)

            elif 'data' not in response: # Error
                return
            elif response['data']['event'] is None: # Error
                return
            elif response['data']['event']['sets']['nodes'] is None: # Error
                return
            elif response['data']['event']['sets']['nodes'] == []: # If pagination completed
                done = True
            
            print("Page {}".format(i)) # Console logging
            i += 1 # iteration for next time

            if type(response) is not int:
                for s in response['data']['event']['sets']['nodes']: # Iterate through all sets
                    bad_set = False
                    try:
                        player1 = s['slots'][0]['entrant']['participants'][0]['player']['user']['slug'].split('/')[1] # Gets user slug of player #1
                    except(TypeError, AttributeError) as error:
                        bad_set = True
                        print("Player with tag {tag} didn't have a user account".
                            format(tag=s['slots'][0]['entrant']['participants'][0]['player']['gamerTag']))
                    except(IndexError):
                        bad_set = True
                        print("Bugged set, no results")
                        
                    try:
                        player2 = s['slots'][1]['entrant']['participants'][0]['player']['user']['slug'].split('/')[1] # Gets user slug of player #2
                    except(TypeError, AttributeError) as error:
                        bad_set = True
                        print("Player with tag {tag} didn't have a user account".
                            format(tag=s['slots'][1]['entrant']['participants'][0]['player']['gamerTag']))
                    except(IndexError):
                        bad_set = True
                        print("Bugged set, no results")

                    if not bad_set:
                        if (player1 in players or player2 in players): # If either player is in the list
                            if (s not in sets): # Prevent duplicate sets
                                sets.append(s) # Append set to sets list
                

        results[e] = {
            # Will add more info
            # 'tournamentName': e['tournament']['name'],
            # 'tournamentId': e['tournament']['name'],
            # 'eventName': e['name'],
            # 'eventId': e['id'],
            'sets': sets
        }

    if save_json: # Outputting json file if flag activated
        with open('tournament_results.json', 'w+', encoding='utf-8') as outfile:
            json.dump(results, outfile, indent=4)

    return results
